import os.path as osp

import yaml

from .config import Config

__all__ = ['load', 'save']


def load(fpath, *, recursive=True):
    if not osp.exists(fpath):
        raise FileNotFoundError(fpath)

    fpaths = [fpath]
    if recursive:
        while fpath:
            fpath = osp.dirname(fpath)
            for fname in ['default.yaml', 'default.yml']:
                fpaths.append(osp.join(fpath, fname))
    fpaths = fpaths[::-1]

    configs = Config()
    for fpath in fpaths:
        if osp.exists(fpath):
            with open(fpath, 'r') as fp:
                configs.update(yaml.safe_load(fp))
    return configs


def save(fpath, configs):
    if not isinstance(configs, Config):
        raise TypeError(type(configs))

    with open(fpath, 'w') as fp:
        yaml.safe_dump(configs.dict(), fp)
